==> cli-1.1.8.tgz: package/config/alias.js <==
const path = require('path');

exports.alias = {
  '@babel/runtime/regenerator': path.join(
    __dirname,
    '../node_modules/@babel/runtime/regenerator',
  ),
  'core-js': path.join(__dirname, '../node_modules/core-js'),

  // react框架
  'react': path.join(__dirname, '../node_modules/react'),
  'react-dom': path.join(__dirname, '../node_modules/react-dom'),
  'dva': path.join(__dirname, '../node_modules/dva'),
  'react-router': path.join(__dirname, '../node_modules/react-router'),
  'react-router-dom': path.join(__dirname, '../node_modules/react-router-dom'),
  'history': path.join(__dirname, '../node_modules/history'),

  // UI框架
  'antd': path.join(__dirname, '../node_modules/antd'),
  '@ant-design': path.join(__dirname, '../node_modules/@ant-design'),
  '@ctrl/tinycolor': path.join(__dirname, '../node_modules/@ctrl/tinycolor'),
  'rc-util': path.join(__dirname, '../node_modules/rc-util'),

  // 第三方工具
  'lodash': path.join(__dirname, '../node_modules/lodash'),
  'moment': path.join(__dirname, '../node_modules/dayjs'),
  'dayjs': path.join(__dirname, '../node_modules/dayjs'),
  'echarts': path.join(__dirname, '../node_modules/echarts'),
  'monaco-editor': path.join(__dirname, '../node_modules/monaco-editor'),
  '@emotion/css': path.join(__dirname, '../node_modules/@emotion/css'),
  '@lcdp/offline-plugin': path.join(__dirname, '../node_modules/@lcdp/offline-plugin'),
  'react-quill': path.join(__dirname, '../node_modules/react-quill'),

  // 自定义工具
  'import-remote-module': path.join(__dirname, '../node_modules/import-remote-module'),
  'code-math': path.join(__dirname, '../node_modules/code-math'),

}

==> cli-1.1.9.tgz: package/config/alias.js <==
const path = require('path');

exports.alias = {
  '@babel/runtime/regenerator': path.join(
    __dirname,
    '../node_modules/@babel/runtime/regenerator',
  ),
  'core-js': path.join(__dirname, '../node_modules/core-js'),

  // react框架
  'react': path.join(__dirname, '../node_modules/react'),
  'react-dom': path.join(__dirname, '../node_modules/react-dom'),
  'dva': path.join(__dirname, '../node_modules/dva'),
  'react-router': path.join(__dirname, '../node_modules/react-router'),
  'react-router-dom': path.join(__dirname, '../node_modules/react-router-dom'),
  'history': path.join(__dirname, '../node_modules/history'),

  // UI框架
  'antd': path.join(__dirname, '../node_modules/antd'),
  '@ant-design': path.join(__dirname, '../node_modules/@ant-design'),
  '@ctrl/tinycolor': path.join(__dirname, '../node_modules/@ctrl/tinycolor'),
  // 'rc-util': path.join(__dirname, '../node_modules/rc-util'),

  // 第三方工具
  'lodash': path.join(__dirname, '../node_modules/lodash'),
  'moment': path.join(__dirname, '../node_modules/moment'),
  'dayjs': path.join(__dirname, '../node_modules/dayjs'),
  'echarts': path.join(__dirname, '../node_modules/echarts'),
  'monaco-editor': path.join(__dirname, '../node_modules/monaco-editor'),
  '@emotion/css': path.join(__dirname, '../node_modules/@emotion/css'),
  '@lcdp/offline-plugin': path.join(__dirname, '../node_modules/@lcdp/offline-plugin'),
  'react-quill': path.join(__dirname, '../node_modules/react-quill'),

  // 自定义工具
  'import-remote-module': path.join(__dirname, '../node_modules/import-remote-module'),
  //'@icode-run/utils': path.join(__dirname, '../node_modules/@icode-run/utils'),
  '@icode-run/utils': path.join(__dirname, '../../icode-component/packages/utils'),
}
